summaryrefslogtreecommitdiffstats
path: root/generic/tclTest.c
diff options
context:
space:
mode:
authorstanton <stanton>1999-02-01 21:29:48 (GMT)
committerstanton <stanton>1999-02-01 21:29:48 (GMT)
commit698e7bfaf6014325ebbdf40634e3d9d9c0c28aca (patch)
tree7091931bbbe9926769ef521c09cb774b668ee6d9 /generic/tclTest.c
parent3e2cd02657427f0858bc981092e85a6c1feae1a6 (diff)
downloadtcl-698e7bfaf6014325ebbdf40634e3d9d9c0c28aca.zip
tcl-698e7bfaf6014325ebbdf40634e3d9d9c0c28aca.tar.gz
tcl-698e7bfaf6014325ebbdf40634e3d9d9c0c28aca.tar.bz2
* generic/tclBasic.c:
* generic/tclCmdAH.c: * generic/tclCmdIL.c: * generic/tclCmdMZ.c: * generic/tclExecute.c: * generic/tclHistory.c: * generic/tclIO.c: * generic/tclIOUtil.c: * generic/tclInterp.c: * generic/tclMain.c: * generic/tclNamesp.c: * generic/tclParse.c: * generic/tclProc.c: * generic/tclTest.c: * generic/tclTimer.c: * generic/tcl.h: Made eval interfaces compatible with 8.0 by renaming Tcl_EvalObj to Tcl_EvalObjEx, renaming Tcl_Eval2 to Tcl_EvalEx and restoring Tcl_EvalObj and Tcl_GlobalEvalObj interfaces so they match Tcl 8.0.
Diffstat (limited to 'generic/tclTest.c')
-rw-r--r--generic/tclTest.c22
1 files changed, 11 insertions, 11 deletions
diff --git a/generic/tclTest.c b/generic/tclTest.c
index 2400d0a..c7eba49 100644
--- a/generic/tclTest.c
+++ b/generic/tclTest.c
@@ -12,7 +12,7 @@
* See the file "license.terms" for information on usage and redistribution
* of this file, and for a DISCLAIMER OF ALL WARRANTIES.
*
- * RCS: @(#) $Id: tclTest.c,v 1.1.2.10 1998/12/10 21:57:48 stanton Exp $
+ * RCS: @(#) $Id: tclTest.c,v 1.1.2.11 1999/02/01 21:29:55 stanton Exp $
*/
#define TCL_TEST
@@ -187,7 +187,7 @@ static int TestdstringCmd _ANSI_ARGS_((ClientData dummy,
static int TestencodingObjCmd _ANSI_ARGS_((ClientData dummy,
Tcl_Interp *interp, int objc,
Tcl_Obj *CONST objv[]));
-static int Testeval2ObjCmd _ANSI_ARGS_((ClientData dummy,
+static int TestevalexObjCmd _ANSI_ARGS_((ClientData dummy,
Tcl_Interp *interp, int objc,
Tcl_Obj *CONST objv[]));
static int TestevalobjvObjCmd _ANSI_ARGS_((ClientData dummy,
@@ -358,7 +358,7 @@ Tcltest_Init(interp)
(Tcl_CmdDeleteProc *) NULL);
Tcl_CreateObjCommand(interp, "testencoding", TestencodingObjCmd, (ClientData) 0,
(Tcl_CmdDeleteProc *) NULL);
- Tcl_CreateObjCommand(interp, "testeval2", Testeval2ObjCmd,
+ Tcl_CreateObjCommand(interp, "testevalex", TestevalexObjCmd,
(ClientData) 0, (Tcl_CmdDeleteProc *) NULL);
Tcl_CreateObjCommand(interp, "testevalobjv", TestevalobjvObjCmd,
(ClientData) 0, (Tcl_CmdDeleteProc *) NULL);
@@ -1462,10 +1462,10 @@ EncodingFreeProc(clientData)
/*
*----------------------------------------------------------------------
*
- * Testeval2ObjCmd --
+ * TestevalexObjCmd --
*
* This procedure implements the "testeval2" command. It is
* used to test Tcl_Eval2.
*
* Results:
* A standard Tcl result.
@@ -1477,7 +1477,7 @@ EncodingFreeProc(clientData)
*/
static int
-Testeval2ObjCmd(dummy, interp, objc, objv)
+TestevalexObjCmd(dummy, interp, objc, objv)
ClientData dummy; /* Not used. */
Tcl_Interp *interp; /* Current interpreter. */
int objc; /* Number of arguments. */
@@ -1490,7 +1490,7 @@ Testeval2ObjCmd(dummy, interp, objc, objv)
if (objc == 1) {
/*
* The command was invoked with no arguments, so just toggle
* the flag that determines whether we use Tcl_Eval2.
*/
if (iPtr->flags & USE_EVAL_DIRECT) {
@@ -1520,14 +1520,14 @@ Testeval2ObjCmd(dummy, interp, objc, objv)
/*
* Note, we have to set the USE_EVAL_DIRECT flag in the interpreter
* in addition to calling Tcl_Eval2. This is needed so that even nested
* commands are evaluated directly.
*/
oldFlags = iPtr->flags;
iPtr->flags |= USE_EVAL_DIRECT;
string = Tcl_GetStringFromObj(objv[1], &length);
- code = Tcl_Eval2(interp, string, length, flags);
+ code = Tcl_EvalEx(interp, string, length, flags);
iPtr->flags = (iPtr->flags & ~USE_EVAL_DIRECT)
| (oldFlags & USE_EVAL_DIRECT);
return code;
@@ -3828,7 +3828,7 @@ TestsaveresultCmd(dummy, interp, objc, objv)
Tcl_SaveResult(interp, &state);
if (((enum options) index) == RESULT_OBJECT) {
- result = Tcl_EvalObj(interp, objv[2], 0);
+ result = Tcl_EvalObjEx(interp, objv[2], 0);
} else {
result = Tcl_Eval(interp, Tcl_GetString(objv[2]));
}
@@ -1462,10 +1462,10 @@ EncodingFreeProc(clientData)
*
- * This procedure implements the "testeval2" command. It is
- * used to test Tcl_Eval2.
+ * This procedure implements the "testevalex" command. It is
+ * used to test Tcl_EvalEx.
*
* Results:
@@ -1490,7 +1490,7 @@ Testeval2ObjCmd(dummy, interp, objc, objv)
/*
* The command was invoked with no arguments, so just toggle
- * the flag that determines whether we use Tcl_Eval2.
+ * the flag that determines whether we use Tcl_EvalEx.
*/
if (iPtr->flags & USE_EVAL_DIRECT) {
@@ -1520,14 +1520,14 @@ Testeval2ObjCmd(dummy, interp, objc, objv)
/*
* Note, we have to set the USE_EVAL_DIRECT flag in the interpreter
- * in addition to calling Tcl_Eval2. This is needed so that even nested
+ * in addition to calling Tcl_EvalEx. This is needed so that even nested
* commands are evaluated directly.
*/